@@ -5,6 +5,7 @@ from .shared import validate_dates, validate_list_dates, validate_list_duplicate
     validate_list_term_percent
 from .practice import validate_cropResidueManagement
 from .product import validate_economicValueShare
+from .data_completeness import validate_dataCompleteness
 
 
 SITE_TYPES_1ha = [
@@ -94,7 +95,8 @@ def validate_cycle(cycle: dict):
         validate_cycle_dates(cycle),
         validate_cycleDuration(cycle) if _should_validate_cycleDuration(cycle) else True,
         validate_altStartDate(cycle) if 'altStartDate' in cycle else True,
-        validate_startDate(cycle) if 'startDate' in cycle else True
+        validate_startDate(cycle) if 'startDate' in cycle else True,
+        validate_dataCompleteness(cycle.get('dataCompleteness'))
     ] + _flatten([
         validate_list_dates(cycle, 'emissions'),
         validate_list_min_max(cycle, 'emissions'),
@@ -127,13 +129,6 @@ def validate_cycle(cycle: dict):
         validate_relDays(cycle, 'products'),
         validate_list_min_max(cycle, 'products'),
         validate_list_term_percent(cycle, 'products'),
-        validate_list_duplicates(cycle, 'products', [
-            'term.@id',
-            'destination.@id',
-            'source.id',
-            'methodDescription',
-            'relDays'
-        ]),
         validate_economicValueShare(cycle.get('products'))
     ] if 'products' in cycle else []) + _flatten([
         validate_list_dates(cycle, 'practices'),
