@@ -226,7 +226,10 @@ class TestValidatorsShared(unittest.TestCase):
         self.assertEqual(validate_coordinates(node), {
             'level': 'error',
             'dataPath': '.country',
-            'message': 'does not contain latitude and longitude'
+            'message': 'does not contain latitude and longitude',
+            'params': {
+                'gadmId': 'GADM-GBR'
+            }
         })
 
     def test_need_validate_coordinates(self):
